@@ -42,39 +42,39 @@
 namespace msXpSlibmass
 {
 
-	//! The AtomCount class provides an atom and a count of that atom.
-	/*!
+//! The AtomCount class provides an atom and a count of that atom.
+/*!
 
-		The AtomCount class derives from Atom, and adds a member datum representing
-		the number of times that the atom occurs (an occurrence count). This class is
-		used during the parsing of Formula instances.
+  The AtomCount class derives from Atom, and adds a member datum representing
+  the number of times that the atom occurs (an occurrence count). This class is
+  used during the parsing of Formula instances.
 
 */
-	class AtomCount : public Atom
-	{
-		private:
-			//! Number of times that the atom occurs (its count).
-			int m_count;
+class AtomCount : public Atom
+{
+  private:
+  //! Number of times that the atom occurs (its count).
+  int m_count;
 
-		public:
-			AtomCount();
-			AtomCount(const AtomCount &);
+  public:
+  AtomCount();
+  AtomCount(const AtomCount &);
 
-			AtomCount *clone() const;
-			void       clone(AtomCount *) const;
-			void       mold(const AtomCount &);
-			AtomCount &operator=(const AtomCount &);
+  AtomCount *clone() const;
+  void clone(AtomCount *) const;
+  void mold(const AtomCount &);
+  AtomCount &operator=(const AtomCount &);
 
-			void setCount(int);
-			int  count() const;
+  void setCount(int);
+  int count() const;
 
-			int account(int = 1);
+  int account(int = 1);
 
-			bool accountMasses(const QList<Atom *> &, double * = Q_NULLPTR,
-					double * = Q_NULLPTR, int = 1) const override;
-	};
+  bool accountMasses(const QList<Atom *> &,
+                     double * = Q_NULLPTR,
+                     double * = Q_NULLPTR,
+                     int      = 1) const override;
+};
 
 
 } // namespace msXpSlibmass
-
-
