@@ -31,8 +31,6 @@
  */
 
 
-
-
 #ifndef PEAK_CENTROID_HPP
 #define PEAK_CENTROID_HPP
 
@@ -48,43 +46,44 @@
 namespace msXpSlibmass
 {
 
-  class PeakCentroid
-  {
-    protected:
-    // m/z ratio.
-    double m_mz;
+class PeakCentroid
+{
+  protected:
+  // m/z ratio.
+  double m_mz;
 
-    // Relative intensity of this peak with respect to all the others
-    // in the pattern.
-    double m_relativeIntensity;
+  // Relative intensity of this peak with respect to all the others
+  // in the pattern.
+  double m_relativeIntensity;
 
-    // Probability of occurrence.
-    double m_probability;
+  // Probability of occurrence.
+  double m_probability;
 
-    public:
-    PeakCentroid(double /* mz */, double /* relIntensity */,
-                 double /* probability */);
-    PeakCentroid(const PeakCentroid &);
+  public:
+  PeakCentroid(double /* mz */,
+               double /* relIntensity */,
+               double /* probability */);
+  PeakCentroid(const PeakCentroid &);
 
-    ~PeakCentroid();
+  ~PeakCentroid();
 
-    PeakCentroid *clone() const;
-    void          clone(PeakCentroid *) const;
-    void          mold(const PeakCentroid &);
-    PeakCentroid &operator=(const PeakCentroid &);
+  PeakCentroid *clone() const;
+  void clone(PeakCentroid *) const;
+  void mold(const PeakCentroid &);
+  PeakCentroid &operator=(const PeakCentroid &);
 
-    void   setMz(double);
-    double mz() const;
+  void setMz(double);
+  double mz() const;
 
-    void    setProbability(double);
-    void    incrementProbability(double);
-    double  probability() const;
-    QString probability(int decimalPlaces) const;
+  void setProbability(double);
+  void incrementProbability(double);
+  double probability() const;
+  QString probability(int decimalPlaces) const;
 
-    void    setRelativeIntensity(double);
-    double  relativeIntensity() const;
-    QString relativeIntensity(int decimalPlaces) const;
-  };
+  void setRelativeIntensity(double);
+  double relativeIntensity() const;
+  QString relativeIntensity(int decimalPlaces) const;
+};
 
 } // namespace msXpSlibmass
 
