@@ -31,7 +31,6 @@
  */
 
 
-
 #pragma once
 
 
@@ -50,46 +49,40 @@
 
 namespace msXpSlibmass
 {
-	class Trace;
+class Trace;
 
-	class TraceJsPrototype
-		:
-			public QObject,
-			public QScriptable
-	{
-		Q_OBJECT
+class TraceJsPrototype : public QObject, public QScriptable
+{
+  Q_OBJECT
 
-		private:
+  private:
+  Trace *thisTrace() const;
 
-			Trace *thisTrace() const;
+  public:
+  TraceJsPrototype(QObject *parent = 0);
+  ~TraceJsPrototype();
 
-		public:
+  public slots:
 
-			TraceJsPrototype(QObject *parent = 0);
-			~TraceJsPrototype();
+  int initialize();
 
-			public slots:
+  int initializeOneArgument();
+  int initializeTwoArguments();
+  int initializeFourArguments();
 
-				int initialize();
+  QList<double> keyArray() const;
+  QList<double> valArray() const;
 
-				int initializeOneArgument();
-				int initializeTwoArguments();
-				int initializeFourArguments();
+  QString asText();
 
-			QList<double> keyArray() const;
-			QList<double> valArray() const;
+  bool exportToFile(const QString &fileName);
 
-			QString asText();
+  double valSum() const;
 
-			bool exportToFile(const QString &fileName);
+  int combine();
+  int subtract();
 
-			double valSum() const;
-
-			int combine();
-			int subtract();
-
-			QScriptValue valueOf() const;
-	};
+  QScriptValue valueOf() const;
+};
 
 } // namespace msXpSlibmass
-
