@@ -31,9 +31,6 @@
  */
 
 
-
-
-
 /////////////////////// Qt includes
 #include <QDir>
 #include <QMessageBox>
@@ -47,54 +44,51 @@ namespace msXpSmassXpert
 {
 
 
-	Application::Application(int &argc, char **argv, const QString &moduleName)
-		:
-			QApplication{argc, argv},
-			m_moduleName{moduleName}
-	{
-		QPixmap splashPixmap(":/images/splashscreen.png");
+Application::Application(int &argc, char **argv, const QString &moduleName)
+  : QApplication{argc, argv}, m_moduleName{moduleName}
+{
+  QPixmap splashPixmap(":/images/splashscreen.png");
 
-		mpa_splash = new QSplashScreen(splashPixmap, Qt::WindowStaysOnTopHint);
-		mpa_splash->show();
+  mpa_splash = new QSplashScreen(splashPixmap, Qt::WindowStaysOnTopHint);
+  mpa_splash->show();
 
-		QTimer::singleShot(2000, this, SLOT(destroySplash()));
+  QTimer::singleShot(2000, this, SLOT(destroySplash()));
 
 
-		// We now have to perform a number of initialization steps.
+  // We now have to perform a number of initialization steps.
 
-		QCoreApplication::setOrganizationName(m_moduleName);
-		QCoreApplication::setOrganizationDomain("msxpertsuite.org");
-		QCoreApplication::setApplicationName(m_moduleName);
+  QCoreApplication::setOrganizationName(m_moduleName);
+  QCoreApplication::setOrganizationDomain("msxpertsuite.org");
+  QCoreApplication::setApplicationName(m_moduleName);
 
-		QString pixmapFileName = ":/images/msxpertsuite-icon-32.png";
-		QPixmap iconPixmap(pixmapFileName);
-		QIcon icon(iconPixmap);
+  QString pixmapFileName = ":/images/msxpertsuite-icon-32.png";
+  QPixmap iconPixmap(pixmapFileName);
+  QIcon icon(iconPixmap);
 
-		// The default window icon.
-		setWindowIcon(icon);
-
-	}
+  // The default window icon.
+  setWindowIcon(icon);
+}
 
 
-	Application::~Application()
-	{
-	}
+Application::~Application()
+{
+}
 
 
-	QString
-	Application::moduleName()
-	{
-		return m_moduleName;
-	}
+QString
+Application::moduleName()
+{
+  return m_moduleName;
+}
 
 
-	void
-		Application::destroySplash()
-		{
-			delete mpa_splash;
+void
+Application::destroySplash()
+{
+  delete mpa_splash;
 
-			mpa_splash = 0;
-		}
+  mpa_splash = 0;
+}
 
 
 } // namespace msXpSmassXpert
