@@ -31,8 +31,6 @@
  */
 
 
-
-
 #ifndef MZ_LAB_OUTPUT_OLIGOMER_TABLE_VIEW_SORT_PROXY_MODEL_HPP
 #define MZ_LAB_OUTPUT_OLIGOMER_TABLE_VIEW_SORT_PROXY_MODEL_HPP
 
@@ -44,17 +42,16 @@
 namespace msXpSmassXpert
 {
 
-  class MzLabOutputOligomerTableViewSortProxyModel
-    : public QSortFilterProxyModel
-  {
-    private:
-    protected:
-    bool lessThan(const QModelIndex &, const QModelIndex &) const;
+class MzLabOutputOligomerTableViewSortProxyModel : public QSortFilterProxyModel
+{
+  private:
+  protected:
+  bool lessThan(const QModelIndex &, const QModelIndex &) const;
 
-    public:
-    MzLabOutputOligomerTableViewSortProxyModel(QObject * = 0);
-    ~MzLabOutputOligomerTableViewSortProxyModel();
-  };
+  public:
+  MzLabOutputOligomerTableViewSortProxyModel(QObject * = 0);
+  ~MzLabOutputOligomerTableViewSortProxyModel();
+};
 
 } // namespace msXpSmassXpert
 
