@@ -31,15 +31,12 @@
  */
 
 
-
-
-
-#include<QVBoxLayout>
-#include<QLabel>
-#include<QFile>
-#include<QFileDialog>
-#include<QMessageBox>
-#include<QDebug>
+#include <QVBoxLayout>
+#include <QLabel>
+#include <QFile>
+#include <QFileDialog>
+#include <QMessageBox>
+#include <QDebug>
 
 #include <massxpert/gui/SeqToolsDlg.hpp>
 
@@ -48,13 +45,12 @@ namespace msXpSmassXpert
 {
 
 
-SeqToolsDlg::SeqToolsDlg (QWidget *parent)
-  : QDialog (parent, Qt::Dialog)
+SeqToolsDlg::SeqToolsDlg(QWidget *parent) : QDialog(parent, Qt::Dialog)
 {
   mp_parent = static_cast<QMainWindow *>(parent);
 
   m_strictCodeLength = false;
-  m_strictCodeCase = false;
+  m_strictCodeCase   = false;
 
   QVBoxLayout *mainLayout = new QVBoxLayout;
 
@@ -81,10 +77,7 @@ SeqToolsDlg::SeqToolsDlg (QWidget *parent)
 
   setWindowTitle(tr("Sequence Manipulation Tools Plugin"));
 
-  connect(mp_parent,
-	   SIGNAL(aboutToClose()),
-	   this,
-	   SLOT(parentClosing()));
+  connect(mp_parent, SIGNAL(aboutToClose()), this, SLOT(parentClosing()));
 }
 
 
@@ -98,17 +91,17 @@ SeqToolsDlg::parentClosing()
 void
 SeqToolsDlg::createEditorGroupBox()
 {
-    mp_editorGroupBox = new QGroupBox(tr("Manipulated Sequences"));
+  mp_editorGroupBox = new QGroupBox(tr("Manipulated Sequences"));
 
-    QHBoxLayout *layout = new QHBoxLayout;
+  QHBoxLayout *layout = new QHBoxLayout;
 
-    mp_inputEditor = new QTextEdit;
-    layout->addWidget(mp_inputEditor);
+  mp_inputEditor = new QTextEdit;
+  layout->addWidget(mp_inputEditor);
 
-    mp_outputEditor = new QTextEdit;
-    layout->addWidget(mp_outputEditor);
+  mp_outputEditor = new QTextEdit;
+  layout->addWidget(mp_outputEditor);
 
-    mp_editorGroupBox->setLayout(layout);
+  mp_editorGroupBox->setLayout(layout);
 }
 
 
@@ -122,28 +115,22 @@ SeqToolsDlg::createActionGroupBox()
   mp_actionComboBox = new QComboBox();
 
   QStringList menuItems = QStringList()
-    << tr("To Upper Case")
-    << tr("To Lower Case")
-    << tr("Dictionary-based Conversion");
+                          << tr("To Upper Case") << tr("To Lower Case")
+                          << tr("Dictionary-based Conversion");
 
   mp_actionComboBox->addItems(menuItems);
 
   layout->addWidget(mp_actionComboBox);
 
   mp_executePushButton = new QPushButton(tr("&Execute"));
-  connect(mp_executePushButton,
-	  SIGNAL(clicked()),
-	  this,
-	  SLOT(execute()));
+  connect(mp_executePushButton, SIGNAL(clicked()), this, SLOT(execute()));
 
   layout->addWidget(mp_executePushButton);
 
   mp_loadDicPushButton = new QPushButton(tr("&Load Dictionary"));
 
-  connect(mp_loadDicPushButton,
-	  SIGNAL(clicked()),
-	  this,
-	  SLOT(loadDictionary()));
+  connect(
+    mp_loadDicPushButton, SIGNAL(clicked()), this, SLOT(loadDictionary()));
 
   layout->addWidget(mp_loadDicPushButton);
 
@@ -157,7 +144,7 @@ SeqToolsDlg::loadDictionary()
 
   // Reinitialize the two critical variables
   m_strictCodeLength = false;
-  m_strictCodeCase = false;
+  m_strictCodeCase   = false;
   // as it is possible to load a different dictionary without having
   // to close the dialog.
 
@@ -170,9 +157,10 @@ SeqToolsDlg::loadDictionary()
   // Pro>P
 
   QString filePath =
-    QFileDialog::getOpenFileName(this, tr("Open Dictionary File"),
-				  QDir::homePath(),
-				  tr("Dictionary files(*.dic)"));
+    QFileDialog::getOpenFileName(this,
+                                 tr("Open Dictionary File"),
+                                 QDir::homePath(),
+                                 tr("Dictionary files(*.dic)"));
 
   if(!QFile::exists(filePath))
     return;
@@ -183,7 +171,7 @@ SeqToolsDlg::loadDictionary()
 
   qint64 lineLength;
   QString line;
-  char buffer [1024];
+  char buffer[1024];
 
   QFile file(filePath);
 
@@ -202,83 +190,83 @@ SeqToolsDlg::loadDictionary()
       line = buffer;
 
       if(line.startsWith('#'))
-	{
-	  lineLength = file.readLine(buffer, sizeof(buffer));
-	  continue;
-	}
+        {
+          lineLength = file.readLine(buffer, sizeof(buffer));
+          continue;
+        }
 
       if(line.simplified() == "strictCodeLength")
-	{
-	  m_strictCodeLength = true;
+        {
+          m_strictCodeLength = true;
 
-	  lineLength = file.readLine(buffer, sizeof(buffer));
-	  continue;
-	}
+          lineLength = file.readLine(buffer, sizeof(buffer));
+          continue;
+        }
 
-        if(line.simplified() == "strictCodeCase")
-	{
-	  m_strictCodeCase = true;
+      if(line.simplified() == "strictCodeCase")
+        {
+          m_strictCodeCase = true;
 
-	  lineLength = file.readLine(buffer, sizeof(buffer));
-	  continue;
-	}
+          lineLength = file.readLine(buffer, sizeof(buffer));
+          continue;
+        }
 
       QStringList stringList = line.split(">", QString::SkipEmptyParts);
 
       if(stringList.size() != 2)
-	{
-	  QMessageBox::warning(this,
-				tr("Sequence Manipulation Tools Plugin"),
-				tr("Failed to load dictionary."),
-				QMessageBox::Ok);
+        {
+          QMessageBox::warning(this,
+                               tr("Sequence Manipulation Tools Plugin"),
+                               tr("Failed to load dictionary."),
+                               QMessageBox::Ok);
 
-	  m_dictionaryLoaded = false;
-	  file.close();
-	  return;
-	}
+          m_dictionaryLoaded = false;
+          file.close();
+          return;
+        }
 
       if(stringList.last().endsWith("\r\n"))
-	stringList.last().chop(2);
+        stringList.last().chop(2);
       else if(stringList.last().endsWith('\n'))
-	stringList.last().chop(1);
+        stringList.last().chop(1);
 
       if(stringList.first().contains(QRegExp("[0-9]")))
-	{
-	  bool ok = false;
-	  m_inputCodeLength = stringList.first().toInt(&ok, 10);
+        {
+          bool ok           = false;
+          m_inputCodeLength = stringList.first().toInt(&ok, 10);
 
-	  if(!m_inputCodeLength && !ok)
-	    {
-	      QMessageBox::warning(this,
-				    tr("Sequence Manipulation Tools Plugin"),
-				    tr("Failed to load dictionary."),
-				    QMessageBox::Ok);
+          if(!m_inputCodeLength && !ok)
+            {
+              QMessageBox::warning(this,
+                                   tr("Sequence Manipulation Tools Plugin"),
+                                   tr("Failed to load dictionary."),
+                                   QMessageBox::Ok);
 
-	      m_dictionaryLoaded = false;
-	      file.close();
-	      return;
-	    }
+              m_dictionaryLoaded = false;
+              file.close();
+              return;
+            }
 
-	  ok = false;
+          ok = false;
 
-	  m_outputCodeLength = stringList.last().toInt(&ok, 10);
+          m_outputCodeLength = stringList.last().toInt(&ok, 10);
 
-	  if(!m_outputCodeLength && !ok)
-	    {
-	      QMessageBox::warning(this,
-				    tr("Sequence Manipulation Tools Plugin"),
-				    tr("Failed to load dictionary."),
-				    QMessageBox::Ok);
+          if(!m_outputCodeLength && !ok)
+            {
+              QMessageBox::warning(this,
+                                   tr("Sequence Manipulation Tools Plugin"),
+                                   tr("Failed to load dictionary."),
+                                   QMessageBox::Ok);
 
-	      m_dictionaryLoaded = false;
-	      file.close();
-	      return;
-	    }
+              m_dictionaryLoaded = false;
+              file.close();
+              return;
+            }
 
-	  lineLength = file.readLine(buffer, sizeof(buffer));
+          lineLength = file.readLine(buffer, sizeof(buffer));
 
-	  continue;
-	}
+          continue;
+        }
 
       // We can now feed the dictionary hash. But, if the character
       // case is not important, then set the first item of the hash to
@@ -287,37 +275,38 @@ SeqToolsDlg::loadDictionary()
       // whatever case for the text.
 
       if(!m_strictCodeCase)
-	{
-	  m_dictionaryHash.insert(stringList.first().toUpper(), stringList.last());
-	}
+        {
+          m_dictionaryHash.insert(stringList.first().toUpper(),
+                                  stringList.last());
+        }
       else
-	{
-	  m_dictionaryHash.insert(stringList.first(), stringList.last());
-	}
+        {
+          m_dictionaryHash.insert(stringList.first(), stringList.last());
+        }
 
       lineLength = file.readLine(buffer, sizeof(buffer));
     }
 
   file.close();
 
-//   qDebug() << __FILE__ << __LINE__
-// 	    << "input/output code lengths"
-// 	    << m_inputCodeLength << "/" << m_outputCodeLength;
+  //   qDebug() << __FILE__ << __LINE__
+  // 	    << "input/output code lengths"
+  // 	    << m_inputCodeLength << "/" << m_outputCodeLength;
 
   if(m_dictionaryHash.size())
     m_dictionaryLoaded = true;
   else
     {
       QMessageBox::warning(this,
-			    tr("Sequence Manipulation Tools Plugin"),
-			    tr("Failed to load dictionary."),
-			    QMessageBox::Ok);
+                           tr("Sequence Manipulation Tools Plugin"),
+                           tr("Failed to load dictionary."),
+                           QMessageBox::Ok);
 
       m_dictionaryLoaded = false;
       return;
     }
 
-//   qDebug() << "done loadDictionary";
+  //   qDebug() << "done loadDictionary";
 }
 
 
@@ -351,56 +340,56 @@ SeqToolsDlg::execute()
   else if(comboText == tr("Dictionary-based Conversion"))
     {
       if(!m_dictionaryLoaded)
-	{
-	  QMessageBox::warning(this,
-				tr("Sequence Manipulation Tools Plugin"),
-				tr("Please, load a dictionary first."),
-				QMessageBox::Ok);
-	  return;
-	}
+        {
+          QMessageBox::warning(this,
+                               tr("Sequence Manipulation Tools Plugin"),
+                               tr("Please, load a dictionary first."),
+                               QMessageBox::Ok);
+          return;
+        }
 
       QString docText = mp_inputEditor->toPlainText();
 
       QStringList codeList;
 
       if(!makeCodeList(docText, codeList))
-	{
-	  QMessageBox::warning(this,
-				tr("Sequence Manipulation Tools Plugin"),
-				tr("Failed to parse the input sequence."),
-				QMessageBox::Ok);
-	  return;
-	}
+        {
+          QMessageBox::warning(this,
+                               tr("Sequence Manipulation Tools Plugin"),
+                               tr("Failed to parse the input sequence."),
+                               QMessageBox::Ok);
+          return;
+        }
 
       for(int iter = 0; iter < codeList.size(); iter++)
-	{
-	  QString curString = codeList.at(iter);
+        {
+          QString curString = codeList.at(iter);
 
-	  QHash<QString, QString>::const_iterator hashIter =
-	    m_dictionaryHash.find(curString);
+          QHash<QString, QString>::const_iterator hashIter =
+            m_dictionaryHash.find(curString);
 
-	  if(hashIter != m_dictionaryHash.end())
-	    codeList.replace(iter, hashIter.value());
-	  //curString = hashIter.value();
-	  else
-	    {
-	      QString message = QString(tr("Failed to convert monomer code: %1")
-					 .arg(curString));
+          if(hashIter != m_dictionaryHash.end())
+            codeList.replace(iter, hashIter.value());
+          // curString = hashIter.value();
+          else
+            {
+              QString message = QString(
+                tr("Failed to convert monomer code: %1").arg(curString));
 
-	      QMessageBox::warning(this,
-				    tr("Sequence Manipulation Tools Plugin"),
-				    message,
-				    QMessageBox::Ok);
-	      return;
-	    }
-	}
+              QMessageBox::warning(this,
+                                   tr("Sequence Manipulation Tools Plugin"),
+                                   message,
+                                   QMessageBox::Ok);
+              return;
+            }
+        }
 
       mp_outputEditor->clear();
 
       docText.clear();
 
       for(int iter = 0; iter < codeList.size(); iter++)
-	docText += codeList.at(iter);
+        docText += codeList.at(iter);
 
       mp_outputEditor->setPlainText(docText);
     }
@@ -411,7 +400,7 @@ int
 SeqToolsDlg::makeCodeList(QString &text, QStringList &stringList)
 {
   int index = 0;
-  int ret = -1;
+  int ret   = -1;
   QString code;
 
   ret = nextCode(text, &code, &index);
@@ -425,16 +414,16 @@ SeqToolsDlg::makeCodeList(QString &text, QStringList &stringList)
       // whatever case for the text.
 
       if(!m_strictCodeCase)
-	{
-	  stringList.append(code.toUpper());
-	}
+        {
+          stringList.append(code.toUpper());
+        }
       else
-	{
-	  stringList.append(code);
-	}
+        {
+          stringList.append(code);
+        }
 
-//       qDebug() << __FILE__ << __LINE__
-// 	       << "Added code:" << code;
+      //       qDebug() << __FILE__ << __LINE__
+      // 	       << "Added code:" << code;
 
       // index was set to the last character parsed during the
       // nextCode call above. Thus we have to increment that index by
@@ -448,7 +437,7 @@ SeqToolsDlg::makeCodeList(QString &text, QStringList &stringList)
   if(ret == -1)
     return -1;
 
-//   qDebug() << stringList;
+  //   qDebug() << stringList;
 
   return stringList.size();
 }
@@ -478,8 +467,8 @@ SeqToolsDlg::nextCode(QString &text, QString *code, int *index)
 
   int textLength = text.length();
 
-//   qDebug()  << __FILE__ << __LINE__
-// 	    << "index:" << *index;
+  //   qDebug()  << __FILE__ << __LINE__
+  // 	    << "index:" << *index;
 
   // At this point there are differnt situations :
 
@@ -496,81 +485,85 @@ SeqToolsDlg::nextCode(QString &text, QString *code, int *index)
     {
       // Test if we do not go out of the boundaries of the text:
 
-      if((*index >= textLength) ||(*index + m_inputCodeLength) > textLength)
-	{
-	  // We are getting out of boundaries, but there is some text:
+      if((*index >= textLength) || (*index + m_inputCodeLength) > textLength)
+        {
+          // We are getting out of boundaries, but there is some text:
 
-	  int residualCharacters = textLength - *index;
+          int residualCharacters = textLength - *index;
 
-	  // Get those two residual characters.
+          // Get those two residual characters.
 
-	  newCode = text.mid(*index, residualCharacters);
+          newCode = text.mid(*index, residualCharacters);
 
-	  if(!newCode.isEmpty())
-	    {
-	      qDebug()  << __FILE__ << __LINE__
-			<< "Incomplete remaining code: " << newCode;
-	    }
+          if(!newCode.isEmpty())
+            {
+              qDebug() << __FILE__ << __LINE__
+                       << "Incomplete remaining code: " << newCode;
+            }
 
-	  return -1;
-	}
+          return -1;
+        }
 
       // Well we can get a full code.
 
       newCode = text.mid(*index, m_inputCodeLength);
 
-//       qDebug() << __FILE__ << __LINE__
-// 	       << "newCode:" << newCode;
+      //       qDebug() << __FILE__ << __LINE__
+      // 	       << "newCode:" << newCode;
 
       // We should ensure that the code's character case is
       // correct.
 
       if(m_strictCodeCase)
-	{
-	  // This means that the first character of the code
-	  // should be uppercase and all the others
-	  // lowercase. Test this.
+        {
+          // This means that the first character of the code
+          // should be uppercase and all the others
+          // lowercase. Test this.
 
-	  int charIterIndex = 0;
+          int charIterIndex = 0;
 
-	  while(charIterIndex < newCode.length())
-	    {
-	      if(!charIterIndex)
-		{
-		  if(newCode.at(charIterIndex).category() == QChar::Letter_Lowercase)
-		    {
-		      qDebug() << __FILE__ << __LINE__
-			       << "First character of code should be Uppercase:"
-			       << newCode;
+          while(charIterIndex < newCode.length())
+            {
+              if(!charIterIndex)
+                {
+                  if(newCode.at(charIterIndex).category() ==
+                     QChar::Letter_Lowercase)
+                    {
+                      qDebug() << __FILE__ << __LINE__
+                               << "First character of code should be Uppercase:"
+                               << newCode;
 
-		      return -1;
-		    }
-		  else
-		    {
-		      ++charIterIndex;
-		      continue;
-		    }
-		}
-	      else
-		{
-		  if(newCode.at(charIterIndex).category() == QChar::Letter_Uppercase)
-		    {
-		      qDebug() << __FILE__ << __LINE__
-			       << "Non-first character of code should be Lowercase:"
-			       << newCode;
+                      return -1;
+                    }
+                  else
+                    {
+                      ++charIterIndex;
+                      continue;
+                    }
+                }
+              else
+                {
+                  if(newCode.at(charIterIndex).category() ==
+                     QChar::Letter_Uppercase)
+                    {
+                      qDebug()
+                        << __FILE__ << __LINE__
+                        << "Non-first character of code should be Lowercase:"
+                        << newCode;
 
-		      return -1;
-		    }
-		  else
-		    {
-		      ++charIterIndex;
-		      continue;
-		    }
-		}
-	    }
+                      return -1;
+                    }
+                  else
+                    {
+                      ++charIterIndex;
+                      continue;
+                    }
+                }
+            }
 
-	  // At this point we know that the characters are correct in number and in case.
-	}
+          // At this point we know that the characters are correct in number and
+          // in case.
+        }
       // End of
       // if(m_strictCodeCase)
 
@@ -581,8 +574,9 @@ SeqToolsDlg::nextCode(QString &text, QString *code, int *index)
       // Set index to point to the last character that was parsed.
       *index = *index + m_inputCodeLength - 1;
 
-//       qDebug() << __FILE__ << __LINE__
-// 	       << "Setting index to" << *index << "prior to returning from nextCode";
+      //       qDebug() << __FILE__ << __LINE__
+      // 	       << "Setting index to" << *index << "prior to returning from
+      // nextCode";
 
       return code->length();
     }
@@ -602,63 +596,64 @@ SeqToolsDlg::nextCode(QString &text, QString *code, int *index)
       // the codeLength.
 
       if(iter >= m_inputCodeLength)
-	{
-	  iter--;
-	  break;
-	}
+        {
+          iter--;
+          break;
+        }
 
       if(iter + *index >= textLength)
-	break;
+        break;
 
       QChar curChar = text.at(iter + *index);
 
       if(!curChar.isLetter())
-	{
-// 	  qDebug() << __FILE__ << __LINE__
-//                  << "The character is not a letter:"
-// 		    << curChar;
+        {
+          // 	  qDebug() << __FILE__ << __LINE__
+          //                  << "The character is not a letter:"
+          // 		    << curChar;
 
-	  return -1;
-	}
+          return -1;
+        }
 
-      bool isLower =(curChar.category() == QChar::Letter_Lowercase);
+      bool isLower = (curChar.category() == QChar::Letter_Lowercase);
 
       if(iter == 0)
-	{
-	  if(isLower)
-	    {
-// 	      qDebug() << "First character of monomer code might not be"
-// 			<< "lower case; sequence is"
-// 			<< m_monomerText.toAscii();
+        {
+          if(isLower)
+            {
+              // 	      qDebug() << "First character of monomer code might not
+              // be"
+              // 			<< "lower case; sequence is"
+              // 			<< m_monomerText.toAscii();
 
-	      return -1;
-	    }
-	  else
-	    {
-	      // Good, first char is uppercase.
-	      newCode += curChar;
-	    }
-	}
+              return -1;
+            }
+          else
+            {
+              // Good, first char is uppercase.
+              newCode += curChar;
+            }
+        }
       else //(iter != 0)
-	{
-	  // We are not in our first iteration. So either the current
-	  // character is lowercase and we are just continuing to
-	  // iterate into a multi-char monomer code, or the current
-	  // character is uppercase, in which case we are starting to
-	  // iterate in a new monomer code.
+        {
+          // We are not in our first iteration. So either the current
+          // character is lowercase and we are just continuing to
+          // iterate into a multi-char monomer code, or the current
+          // character is uppercase, in which case we are starting to
+          // iterate in a new monomer code.
 
-	  if(isLower)
-	    newCode += curChar;
-	  else
-	    {
-	      // Decrement iter, because this round was for nothing:
-	      // we had "invaded" the next monomer code in sequence,
-	      // which we must not do.
+          if(isLower)
+            newCode += curChar;
+          else
+            {
+              // Decrement iter, because this round was for nothing:
+              // we had "invaded" the next monomer code in sequence,
+              // which we must not do.
 
-	      iter --;
-	      break;
-	    }
-	}
+              iter--;
+              break;
+            }
+        }
 
       iter++;
     }
@@ -672,11 +667,10 @@ SeqToolsDlg::nextCode(QString &text, QString *code, int *index)
   // the sent 'code' object.
 
   *index = *index + iter;
-  *code = newCode;
+  *code  = newCode;
 
   return code->length();
 }
 
 
 } // namespace msXpSmassXpert
-
