@@ -31,8 +31,6 @@
  */
 
 
-
-
 #pragma once
 
 
@@ -68,67 +66,64 @@
 namespace msXpSmassXpert
 {
 
-	//! End of the polymer sequence.
-	enum PolymerEnd
-	{
-		END_NONE  = 0 << 1,
-		END_LEFT  = 1 << 1,
-		END_RIGHT = 2 << 1,
-		END_BOTH  = (END_LEFT | END_RIGHT),
-	};
+//! End of the polymer sequence.
+enum PolymerEnd
+{
+  END_NONE  = 0 << 1,
+  END_LEFT  = 1 << 1,
+  END_RIGHT = 2 << 1,
+  END_BOTH  = (END_LEFT | END_RIGHT),
+};
 
 
-	//! Type of capping.
-	/*! The sequence may be capped at left end , at right end, at both
-	 *  ends or not capped at all.
-	 */
-	enum CapType
-	{
-		CAP_NONE  = 0 << 1,
-		CAP_LEFT  = 1 << 1,
-		CAP_RIGHT = 2 << 1,
-		CAP_BOTH  = (CAP_LEFT | CAP_RIGHT),
-	};
+//! Type of capping.
+/*! The sequence may be capped at left end , at right end, at both
+ *  ends or not capped at all.
+ */
+enum CapType
+{
+  CAP_NONE  = 0 << 1,
+  CAP_LEFT  = 1 << 1,
+  CAP_RIGHT = 2 << 1,
+  CAP_BOTH  = (CAP_LEFT | CAP_RIGHT),
+};
 
 
-	//! Monomer chemical entities.
-	/*! The monomer chemical entities can be nothing or modifications.
-	*/
-	enum MonomerChemEnt
-	{
-		MONOMER_CHEMENT_NONE       = 0 << 1,
-		MONOMER_CHEMENT_MODIF      = 1 << 1,
-		MONOMER_CHEMENT_CROSS_LINK = 1 << 2,
-	};
+//! Monomer chemical entities.
+/*! The monomer chemical entities can be nothing or modifications.
+ */
+enum MonomerChemEnt
+{
+  MONOMER_CHEMENT_NONE       = 0 << 1,
+  MONOMER_CHEMENT_MODIF      = 1 << 1,
+  MONOMER_CHEMENT_CROSS_LINK = 1 << 2,
+};
 
 
-	//! Polymer chemical entities.
-	/*! The polymer chemical entities can be nothing or left end
-	 *  modification or right end modification or both ends modifications.
-	 */
-	enum PolymerChemEnt
-	{
-		POLYMER_CHEMENT_NONE                  = 1 << 0,
-		POLYMER_CHEMENT_LEFT_END_MODIF        = 1 << 1,
-		POLYMER_CHEMENT_FORCE_LEFT_END_MODIF  = 1 << 2,
-		POLYMER_CHEMENT_RIGHT_END_MODIF       = 1 << 3,
-		POLYMER_CHEMENT_FORCE_RIGHT_END_MODIF = 1 << 4,
-		POLYMER_CHEMENT_BOTH_END_MODIF =
-			(POLYMER_CHEMENT_LEFT_END_MODIF | POLYMER_CHEMENT_RIGHT_END_MODIF),
-		POLYMER_CHEMENT_VORCE_BOTH_END_MODIF =
-			(POLYMER_CHEMENT_FORCE_LEFT_END_MODIF |
-			 POLYMER_CHEMENT_FORCE_RIGHT_END_MODIF)
-	};
+//! Polymer chemical entities.
+/*! The polymer chemical entities can be nothing or left end
+ *  modification or right end modification or both ends modifications.
+ */
+enum PolymerChemEnt
+{
+  POLYMER_CHEMENT_NONE                  = 1 << 0,
+  POLYMER_CHEMENT_LEFT_END_MODIF        = 1 << 1,
+  POLYMER_CHEMENT_FORCE_LEFT_END_MODIF  = 1 << 2,
+  POLYMER_CHEMENT_RIGHT_END_MODIF       = 1 << 3,
+  POLYMER_CHEMENT_FORCE_RIGHT_END_MODIF = 1 << 4,
+  POLYMER_CHEMENT_BOTH_END_MODIF =
+    (POLYMER_CHEMENT_LEFT_END_MODIF | POLYMER_CHEMENT_RIGHT_END_MODIF),
+  POLYMER_CHEMENT_VORCE_BOTH_END_MODIF = (POLYMER_CHEMENT_FORCE_LEFT_END_MODIF |
+                                          POLYMER_CHEMENT_FORCE_RIGHT_END_MODIF)
+};
 
 
-	enum HashAccountData
-	{
-		HASH_ACCOUNT_SEQUENCE      = 1 << 0,
-		HASH_ACCOUNT_MONOMER_MODIF = 1 << 1,
-		HASH_ACCOUNT_POLYMER_MODIF = 1 << 2,
-	};
+enum HashAccountData
+{
+  HASH_ACCOUNT_SEQUENCE      = 1 << 0,
+  HASH_ACCOUNT_MONOMER_MODIF = 1 << 1,
+  HASH_ACCOUNT_POLYMER_MODIF = 1 << 2,
+};
 
 
 } // namespace msXpSmassXpert
-
-
