@@ -31,8 +31,6 @@
  */
 
 
-
-
 #pragma once
 
 
@@ -50,44 +48,49 @@
 namespace msXpSmineXpert
 {
 
-	//! The ConsoleWnd class provides a feedback console window.
-	/*!
+//! The ConsoleWnd class provides a feedback console window.
+/*!
 
-		The ConsoleWnd class is available in mineXpert to display a number of
-		message for the user to have feedback on the various tasks running in the
-		program. The widget is a simple multiline edit widget.
+  The ConsoleWnd class is available in mineXpert to display a number of
+  message for the user to have feedback on the various tasks running in the
+  program. The widget is a simple multiline edit widget.
 
-	 */
-	class ConsoleWnd : public QMainWindow
-	{
-		Q_OBJECT
+ */
+class ConsoleWnd : public QMainWindow
+{
+  Q_OBJECT
 
-		private:
-			Ui::ConsoleWnd m_ui;
+  private:
+  Ui::ConsoleWnd m_ui;
 
-			QString m_lastLoggedText;
+  QString m_lastLoggedText;
 
-		protected:
+  protected:
+  //! Name of the application.
+  QString m_applicationName;
 
-			//! Name of the application.
-			QString m_applicationName;
+  void closeEvent(QCloseEvent *event);
 
-			void closeEvent(QCloseEvent *event);
+  public:
+  ConsoleWnd(QWidget *parent, const QString &applicationName);
+  ~ConsoleWnd();
 
-		public:
-			ConsoleWnd(QWidget *parent, const QString &applicationName);
-			~ConsoleWnd();
+  Q_INVOKABLE void writeSettings();
+  Q_INVOKABLE void readSettings();
 
-			Q_INVOKABLE void writeSettings();
-			Q_INVOKABLE void readSettings();
+  void logMessage(QString msg, const QColor &color, bool overwrite = false);
+  Q_INVOKABLE void logMessage(QString msg);
 
-			void logMessage(QString msg, const QColor &color, bool overwrite = false);
-			Q_INVOKABLE void logMessage(QString msg);
-
-			Q_INVOKABLE void hide(){QMainWindow::hide();};
-			Q_INVOKABLE void show(){QMainWindow::show();};
-	};
+  Q_INVOKABLE void
+  hide()
+  {
+    QMainWindow::hide();
+  };
+  Q_INVOKABLE void
+  show()
+  {
+    QMainWindow::show();
+  };
+};
 
 } // namespace msXpSmineXpert
-
-
