@@ -67,6 +67,7 @@
 #include "../nongui/MassSpecDataFileLoaderXy.hpp"
 #include "../nongui/MassSpecDataFileLoaderBrukerXy.hpp"
 #include "../nongui/MassSpecDataFileLoaderDx.hpp"
+#include "IsoSpecDlg.hpp"
 #include "PeakShaperDlg.hpp"
 #include "ScriptingWnd.hpp"
 
@@ -609,15 +610,19 @@ MainWindow::openStreamedMassSpectrometryFileDlg()
 
 //! Create a mass spectrum starting from data in the clipboard.
 void
-MainWindow::createMassSpectrumFromXyText(const QString &text, const QString &title)
+MainWindow::createMassSpectrumFromXyText(const QString &text,
+                                         const QString &title)
 {
   if(text.isEmpty())
     {
       return;
     }
 
-  logConsoleMessage(
-    "Starting the parsing of the mass data text.\n");
+  qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
+
+  logConsoleMessage("Starting the parsing of the mass data text.\n");
+
+  qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
 
   MassSpecDataFileLoaderXy loader;
 
@@ -633,6 +638,8 @@ MainWindow::createMassSpectrumFromXyText(const QString &text, const QString &tit
       return;
     }
 
+  qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
+
   // We can set some more data to the p_massSpecDataSet:
   p_massSpecDataSet->rfileFormat() =
     MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_XY;
@@ -685,6 +692,8 @@ MainWindow::createMassSpectrumFromXyText(const QString &text, const QString &tit
   // Now compute the TIC and plot it. The function returns the plot widget
   // that displays the chromatogram for this mass spec data set.
 
+  qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
+
   statusBarMessage("Calculating the TIC chromatogram...");
   logConsoleMessage("Calculating the TIC chromatogram...\n");
 
@@ -712,8 +721,10 @@ MainWindow::createMassSpectrumFromClipboard()
   QString msData        = clipboard->text();
 
 
-	return createMassSpectrumFromXyText(msData, QString("From clipboard @ %1")
-			.arg(QTime::currentTime().toString("hh:mm:ss.zzz")));
+  return createMassSpectrumFromXyText(
+    msData,
+    QString("From clipboard @ %1")
+      .arg(QTime::currentTime().toString("hh:mm:ss.zzz")));
 }
 
 
@@ -1739,6 +1750,17 @@ MainWindow::makeLoaderConnections(MassSpecDataFileLoader *loader)
 }
 
 
+void
+MainWindow::isoSpecDlg()
+{
+  IsoSpecDlg *iso_spec_dlg_p =
+    new IsoSpecDlg(dynamic_cast<QWidget *>(this), m_moduleName);
+  iso_spec_dlg_p->show();
+  iso_spec_dlg_p->raise();
+  iso_spec_dlg_p->activateWindow();
+}
+
+
 void
 MainWindow::peakShaperDlg()
 {
@@ -1909,11 +1931,20 @@ MainWindow::createMenusAndActions()
   // Utilities menu
   m_utilitiesMenu = menuBar()->addMenu("&Utilities");
 
+  m_isoSpecAct =
+    new QAction("Isotopic cluster calculator", dynamic_cast<QObject *>(this));
+  m_isoSpecAct->setShortcut(QKeySequence("Ctrl+U, I"));
+  m_isoSpecAct->setStatusTip(
+    tr("Calculate the isotopic cluster distribution for a chemical formula"));
+  connect(m_isoSpecAct, &QAction::triggered, this, &MainWindow::isoSpecDlg);
+  m_utilitiesMenu->addAction(m_isoSpecAct);
+
+
   m_peakShaperAct =
-    new QAction("Centroid peak shaper", dynamic_cast<QObject *>(this));
+    new QAction("Peak centroid shaper", dynamic_cast<QObject *>(this));
   m_peakShaperAct->setShortcut(QKeySequence("Ctrl+U, S"));
   m_peakShaperAct->setStatusTip(
-    tr("Shape centroid peak(s) into gaussian/lorentzian peak shape(s)"));
+    tr("Shape peak centroid(s) into gaussian/lorentzian fully shaped peak(s)"));
   connect(
     m_peakShaperAct, &QAction::triggered, this, &MainWindow::peakShaperDlg);
   m_utilitiesMenu->addAction(m_peakShaperAct);
