@@ -166,7 +166,8 @@ class MainWindow : public QMainWindow
   QAction *m_openStreamedMsFileAct;
   QAction *m_openMsClipboardAct;
 
-	QAction *m_peakShaperAct;
+  QAction *m_isoSpecAct;
+  QAction *m_peakShaperAct;
 
   QAction *m_analysisPrefsAct;
   QAction *m_quitAct;
@@ -264,7 +265,8 @@ class MainWindow : public QMainWindow
 
   void xicExtraction();
 
-	void peakShaperDlg();
+  void isoSpecDlg();
+  void peakShaperDlg();
 
   void analysisPrefDlg();
   void showTicChromWnd();
